@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-15/Applications/Cxx/gdcmanon.cxx $
+  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmanon.cxx $
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -33,7 +33,7 @@
 static void PrintVersion()
 {
   std::cout << "gdcmanon: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-07-09 15:35:24 +0200 (Fri, 09 Jul 2010) $";
+  const char date[] = "$Date: 2010-08-18 12:22:07 +0200 (Wed, 18 Aug 2010) $";
   std::cout << date << std::endl;
 }
 
@@ -147,16 +147,6 @@ static bool AnonymizeOneFile(gdcm::Anonymizer &anon, const char *filename, const
       std::cerr << "Could not De-indentify : " << filename << std::endl;
       return false;
       }
-
-    // FIXME:
-    gdcm::FileMetaInformation &fmi = file.GetHeader();
-    //fmi.Remove( gdcm::Tag(0x0002,0x0003) ); // will be regenerated
-    fmi.Remove( gdcm::Tag(0x0002,0x0012) ); // will be regenerated
-    fmi.Remove( gdcm::Tag(0x0002,0x0013) ); //  '   '    '
-    fmi.Remove( gdcm::Tag(0x0002,0x0016) ); //  '   '    '
-    fmi.Remove( gdcm::Tag(0x0002,0x0100) ); //  '   '    ' // PrivateInformationCreatorUID
-    fmi.Remove( gdcm::Tag(0x0002,0x0102) ); //  '   '    ' // PrivateInformation
-
     }
   else if ( reidentify )
     {
@@ -167,6 +157,9 @@ static bool AnonymizeOneFile(gdcm::Anonymizer &anon, const char *filename, const
       }
     }
 
+  gdcm::FileMetaInformation &fmi = file.GetHeader();
+  fmi.Clear();
+
   gdcm::Writer writer;
   writer.SetFileName( outfilename );
   writer.SetFile( file );
