@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-15/Applications/Cxx/gdcmconv.cxx $
+  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-16/Applications/Cxx/gdcmconv.cxx $
 
   Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
@@ -107,7 +107,7 @@ struct SetSQToUndefined
 void PrintVersion()
 {
   std::cout << "gdcmconv: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2010-06-23 18:15:58 +0200 (Wed, 23 Jun 2010) $";
+  const char date[] = "$Date: 2010-08-18 09:54:12 +0200 (Wed, 18 Aug 2010) $";
   std::cout << date << std::endl;
 }
 
@@ -940,12 +940,8 @@ int main (int argc, char *argv[])
     gdcm::DataElement de( gdcm::Tag(0x0002,0x0010) );
     de.SetByteValue( tsuid, strlen(tsuid) );
     de.SetVR( gdcm::Attribute<0x0002, 0x0010>::GetVR() );
+    fmi.Clear();
     fmi.Replace( de );
-    fmi.Remove( gdcm::Tag(0x0002,0x0012) ); // will be regenerated
-    fmi.Remove( gdcm::Tag(0x0002,0x0013) ); //  '   '    '
-    fmi.Remove( gdcm::Tag(0x0002,0x0016) ); //  '   '    '
-    fmi.Remove( gdcm::Tag(0x0002,0x0100) ); //  '   '    ' // PrivateInformationCreatorUID
-    fmi.Remove( gdcm::Tag(0x0002,0x0102) ); //  '   '    ' // PrivateInformation
 
     fmi.SetDataSetTransferSyntax(ts);
 
@@ -1264,6 +1260,12 @@ int main (int argc, char *argv[])
     writer.SetFileName( outfilename.c_str() );
     writer.SetFile( reader.GetFile() );
     //writer.SetFile( fef.GetFile() );
+
+    gdcm::File & file = writer.GetFile();
+    gdcm::FileMetaInformation &fmi = file.GetHeader();
+    fmi.Remove( gdcm::Tag(0x0002,0x0100) ); //  '   '    ' // PrivateInformationCreatorUID
+    fmi.Remove( gdcm::Tag(0x0002,0x0102) ); //  '   '    ' // PrivateInformation
+
     const gdcm::Pixmap &pixout = change.PixmapToPixmapFilter::GetOutput();
     writer.SetPixmap( pixout );
     if( !writer.Write() )
@@ -1327,9 +1329,6 @@ int main (int argc, char *argv[])
     writer.SetPixmap( image );
     writer.SetFileName( outfilename.c_str() );
 
-    gdcm::File& file = writer.GetFile();
-    gdcm::DataSet& ds = file.GetDataSet();
-
     if( !writer.Write() )
       {
       std::cerr << "could not write: " << outfilename << std::endl;
@@ -1376,8 +1375,8 @@ int main (int argc, char *argv[])
     f.SetDataSet(ds);
 #endif
 
-    gdcm::DataSet& ds = reader.GetFile().GetDataSet();
 #if 0
+    gdcm::DataSet& ds = reader.GetFile().GetDataSet();
     gdcm::DataElement de = ds.GetDataElement( gdcm::Tag(0x0010,0x0010) );
     const char patname[] = "John^Doe";
     de.SetByteValue(patname, strlen(patname));
