@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmCryptographicMessageSyntax_h
-#define __gdcmCryptographicMessageSyntax_h
+#ifndef GDCMCRYPTOGRAPHICMESSAGESYNTAX_H
+#define GDCMCRYPTOGRAPHICMESSAGESYNTAX_H
 
 #include "gdcmTypes.h"
 
@@ -49,10 +49,15 @@ public :
     AES256_CIPHER  // '   '
   } CipherTypes;
 
-  void SetCipherType( CipherTypes type);
+  /// Set Cipher Type.
+  /// Default is: AES256_CIPHER
+  void SetCipherType(CipherTypes type);
   CipherTypes GetCipherType() const;
 
+  /// create a PKCS#7 envelopedData structure 
   bool Encrypt(char *output, size_t &outlen, const char *array, size_t len) const;
+
+  /// decrypt content from a PKCS#7 envelopedData structure 
   bool Decrypt(char *output, size_t &outlen, const char *array, size_t len) const;
 
 private:
@@ -63,4 +68,4 @@ private:
 };
 } // end namespace gdcm
 //-----------------------------------------------------------------------------
-#endif //__gdcmCryptographicMessageSyntax_h
+#endif //GDCMCRYPTOGRAPHICMESSAGESYNTAX_H
