@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,10 +12,10 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmDeflateStream_h
-#define __gdcmDeflateStream_h
+#ifndef GDCMDEFLATESTREAM_H
+#define GDCMDEFLATESTREAM_H
 
 #include "zipstreamimpl.h"
 
-#endif //__gdcmDeflateStream_h
+#endif //GDCMDEFLATESTREAM_H
 
