@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmCP246ExplicitDataElement_h
-#define __gdcmCP246ExplicitDataElement_h
+#ifndef GDCMCP246EXPLICITDATAELEMENT_H
+#define GDCMCP246EXPLICITDATAELEMENT_H
 
 #include "gdcmDataElement.h"
 
@@ -45,5 +45,5 @@ public:
 
 #include "gdcmCP246ExplicitDataElement.txx"
 
-#endif //__gdcmCP246ExplicitDataElement_h
+#endif //GDCMCP246EXPLICITDATAELEMENT_H
 
