@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmCSAElement_h
-#define __gdcmCSAElement_h
+#ifndef GDCMCSAELEMENT_H
+#define GDCMCSAELEMENT_H
 
 #include "gdcmTag.h"
 #include "gdcmVM.h"
@@ -25,8 +25,8 @@ namespace gdcm
 {
 /**
  * \brief Class to represent a CSA Element
+ * \see CSAHeader
  */
-
 class GDCM_EXPORT CSAElement
 {
 public:
@@ -171,5 +171,5 @@ inline std::ostream& operator<<(std::ostream &os, const CSAElement &val)
 
 } // end namespace gdcm
 
-#endif //__gdcmCSAElement_h
+#endif //GDCMCSAELEMENT_H
 
