@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmVR_h
-#define __gdcmVR_h
+#ifndef GDCMVR_H
+#define GDCMVR_H
 
 #include "gdcmTag.h"
 #include "gdcmTrace.h"
@@ -163,12 +163,14 @@ public:
   const std::ostream &Write(std::ostream &os) const
     {
     VRType vrfield = VRField;
+    gdcmAssertAlwaysMacro( !IsDual() );
     if( vrfield == VR::INVALID )
       {
       //vrfield = VR::UN;
       }
     const char *vr = GetVRString(vrfield);
-    assert( strlen( vr ) == 2 );
+    //assert( strlen( vr ) == 2 );
+    assert( vr[0] && vr[1] && vr[2] == 0 );
     os.write(vr, 2);
     // See PS 3.5, Data Element Structure With Explicit VR
     if( vrfield & VL32 )
@@ -318,5 +320,5 @@ inline unsigned int VR::GetSize() const
 
 } // end namespace gdcm
 
-#endif //__gdcmVR_h
+#endif //GDCMVR_H
 
