@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmVR16ExplicitDataElement_h
-#define __gdcmVR16ExplicitDataElement_h
+#ifndef GDCMVR16EXPLICITDATAELEMENT_H
+#define GDCMVR16EXPLICITDATAELEMENT_H
 
 #include "gdcmDataElement.h"
 
@@ -46,5 +46,5 @@ public:
 
 #include "gdcmVR16ExplicitDataElement.txx"
 
-#endif //__gdcmVR16ExplicitDataElement_h
+#endif //GDCMVR16EXPLICITDATAELEMENT_H
 
