@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmSeries_h
-#define __gdcmSeries_h
+#ifndef GDCMSERIES_H
+#define GDCMSERIES_H
 
 #include "gdcmTypes.h"
 
@@ -33,4 +33,4 @@ private:
 
 } // end namespace gdcm
 
-#endif //__gdcmSeries_h
+#endif //GDCMSERIES_H
