@@ -12,7 +12,6 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-
 #ifndef GDCMAPPLICATIONENTITY_H
 #define GDCMAPPLICATIONENTITY_H
 
@@ -50,9 +49,12 @@ public:
     // trim leading and trailing white spaces
   }
   void SetBlob(const std::vector<char>& v) {
-    abort(); //TODO
+    (void)v;
+    assert(0); //TODO
   }
   void Print(std::ostream &os) const {
+  (void)os;
+    assert(0); //TODO
   }
 };
 
