@@ -339,7 +339,7 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
       if( !sf ) return false;
       const Fragment &frag = sf->GetFragment(0);
       const ByteValue &bv2 = dynamic_cast<const ByteValue&>(frag.GetValue());
-      gdcm::PixelFormat pf = gdcm::PixelFormat::UINT8;
+      gdcm::PixelFormat pf = GetPixelFormat(); // gdcm::PixelFormat::UINT8;
       codec.SetPixelFormat( pf );
 
       std::stringstream ss;
@@ -370,27 +370,35 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
       }
     // FIXME ! This should be done all the time for all codec:
     // Did PI change or not ?
-    if ( GetPhotometricInterpretation() != codec.GetPhotometricInterpretation() )
+    if ( GetPlanarConfiguration() != codec.GetPlanarConfiguration() )
       {
-      // HACK
-      // YBRisGray.dcm 
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this;
-      i->SetPhotometricInterpretation( codec.GetPhotometricInterpretation() );
+      gdcm::Bitmap *i = (gdcm::Bitmap*)this; (void)i;
+      //i->SetPlanarConfiguration( codec.GetPlanarConfiguration() );
       }
+    // I cannot re-activate the following since I would loose the palette color information
+    // (this is not stored in the JPEG header).
+    //if ( GetPhotometricInterpretation() != codec.GetPhotometricInterpretation() )
+    //  {
+    //  // HACK
+    //  // YBRisGray.dcm 
+    //  gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+    //  i->SetPhotometricInterpretation( codec.GetPhotometricInterpretation() );
+    //  }
     if ( GetPixelFormat() != codec.GetPixelFormat() )
       {
       gdcm::Bitmap *i = (gdcm::Bitmap*)this;
       i->SetPixelFormat( codec.GetPixelFormat() );
       }
-    if ( GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422 
-    || GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL )
-      {
-      gdcm::Bitmap *i = (gdcm::Bitmap*)this;
-      i->SetPhotometricInterpretation( PhotometricInterpretation::RGB );
-      }
+    //if ( GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422 
+    //|| GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL )
+    //  {
+    //  gdcm::Bitmap *i = (gdcm::Bitmap*)this;
+    //  i->SetPhotometricInterpretation( PhotometricInterpretation::RGB );
+    //  }
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     // DermaColorLossLess.dcm has a len of 63531, but DICOM will give us: 63532 ...
     assert( len <= outbv->GetLength() );
     if(buffer) memcpy(buffer, outbv->GetPointer(), len /*outbv->GetLength()*/ );  // FIXME
@@ -434,6 +442,7 @@ bool Bitmap::TryJPEGCodec2(std::ostream &os) const
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     // DermaColorLossLess.dcm has a len of 63531, but DICOM will give us: 63532 ...
     assert( outbv->GetLength() < len );
     //memcpy(buffer, outbv->GetPointer(), outbv->GetLength() );
@@ -466,6 +475,7 @@ bool Bitmap::TryPVRGCodec(char *buffer, bool &lossyflag) const
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     assert( len <= outbv->GetLength() );
     if(buffer) memcpy(buffer, outbv->GetPointer(), len /*outbv->GetLength()*/ );  // FIXME
 
@@ -498,6 +508,7 @@ bool Bitmap::TryKAKADUCodec(char *buffer, bool &lossyflag) const
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     assert( len <= outbv->GetLength() );
     // DermaColorLossLess.dcm has a len of 63531, but DICOM will give us: 63532 ...
     assert( len <= outbv->GetLength() );
@@ -536,6 +547,7 @@ bool Bitmap::TryJPEGLSCodec(char *buffer, bool &lossyflag) const
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     assert( len <= outbv->GetLength() );
     // DermaColorLossLess.dcm has a len of 63531, but DICOM will give us: 63532 ...
     assert( len <= outbv->GetLength() );
@@ -615,6 +627,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     assert( len <= outbv->GetLength() );
     if(buffer) memcpy(buffer, outbv->GetPointer(), len /*outbv->GetLength()*/ );  // FIXME
 
@@ -638,6 +651,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
 bool Bitmap::TryJPEG2000Codec2(std::ostream &os) const
 {
   unsigned long len = GetBufferLength();
+  (void)len;
   const TransferSyntax &ts = GetTransferSyntax();
 
   JPEG2000Codec codec;
@@ -655,6 +669,7 @@ bool Bitmap::TryJPEG2000Codec2(std::ostream &os) const
     const ByteValue *outbv = out.GetByteValue();
     assert( outbv );
     unsigned long check = outbv->GetLength();  // FIXME
+    (void)check;
     //memcpy(buffer, outbv->GetPointer(), outbv->GetLength() );  // FIXME
     os.write(outbv->GetPointer(), outbv->GetLength() );
     return r;
