@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmDICOMDIR_h
-#define __gdcmDICOMDIR_h
+#ifndef GDCMDICOMDIR_H
+#define GDCMDICOMDIR_H
 
 #include "gdcmFileSet.h"
 
@@ -36,4 +36,4 @@ private:
 
 } // end namespace gdcm
 
-#endif //__gdcmDICOMDIR_h
+#endif //GDCMDICOMDIR_H
