@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmDeltaEncodingodec_h
-#define __gdcmDeltaEncodingodec_h
+#ifndef GDCMDELTAENCODINGCODEC_H
+#define GDCMDELTAENCODINGCODEC_H
 
 #include "gdcmImageCodec.h"
 #error do not use
@@ -38,4 +38,4 @@ protected:
 
 } // end namespace gdcm
 
-#endif //__gdcmRAWcodec_h
+#endif //GDCMDELTAENCODINGCODEC_H
