@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmFileExplicitFilter_h
-#define __gdcmFileExplicitFilter_h
+#ifndef GDCMFILEEXPLICITFILTER_H
+#define GDCMFILEEXPLICITFILTER_H
 
 #include "gdcmFile.h"
 
@@ -23,12 +23,18 @@ class Dicts;
 
 /**
  * \brief FileExplicitFilter class
- * \warning changing an implicit dataset to an explicit dataset is NOT a trivial task of
- * simply changing the VR to the dict one:
- *   - One has to make sure SQ is properly set
- *   - One has to recompute the explicit length SQ
- *   - One has to make sure that Vr is valid for the encoding
- *   - One has to make sure that VR 16bits can store the original value length
+ * After changing a file from Implicit to Explicit representation (see
+ * ImageChangeTransferSyntax) one operation is to make sure the VR of each
+ * DICOM attribute are accurate and do match the one from PS 3.6. Indeed when a
+ * file is written in Implicit reprensentation, the VR is not stored directly
+ * in the file.
+ *
+ * \warning changing an implicit dataset to an explicit dataset is NOT a
+ * trivial task of simply changing the VR to the dict one:
+ * \li One has to make sure SQ is properly set
+ * \li One has to recompute the explicit length SQ
+ * \li One has to make sure that VR is valid for the encoding
+ * \li One has to make sure that VR 16bits can store the original value length
  */
 class GDCM_EXPORT FileExplicitFilter
 {
@@ -70,5 +76,5 @@ private:
 
 } // end namespace gdcm
 
-#endif //__gdcmFileExplicitFilter_h
+#endif //GDCMFILEEXPLICITFILTER_H
 
