@@ -58,9 +58,30 @@ bool ImageChangeTransferSyntax::TryRAWCodecIcon(const DataElement &pixelde)
 }
 */
 
+void UpdatePhotometricInterpretation( Bitmap const &input, Bitmap &output )
+{
+  // when decompressing J2K, need to revert to proper photo inter in uncompressed TS:
+  if( input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_RCT
+    || input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_ICT )
+    {
+    output.SetPhotometricInterpretation( PhotometricInterpretation::RGB );
+    }
+  // when decompressing loss jpeg, need to revert to proper photo inter in uncompressed TS:
+  if( input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422 )
+    {
+    output.SetPhotometricInterpretation( PhotometricInterpretation::YBR_FULL );
+    }
+  assert( output.GetPhotometricInterpretation() == PhotometricInterpretation::RGB
+    || output.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL
+    || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME1
+    || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME2
+    || output.GetPhotometricInterpretation() == PhotometricInterpretation::ARGB
+    || output.GetPhotometricInterpretation() == PhotometricInterpretation::PALETTE_COLOR ); // programmer error
+}
+
 bool ImageChangeTransferSyntax::TryRAWCodec(const DataElement &pixelde, Bitmap const &input, Bitmap &output)
 {
-  unsigned long len = input.GetBufferLength();
+  unsigned long len = input.GetBufferLength(); (void)len;
   //assert( len == pixelde.GetByteValue()->GetLength() );
   const TransferSyntax &ts = GetTransferSyntax();
 
@@ -82,18 +103,7 @@ bool ImageChangeTransferSyntax::TryRAWCodec(const DataElement &pixelde, Bitmap c
       }
     DataElement &de = output.GetDataElement();
     de.SetValue( out.GetValue() );
-    // when decompressing J2K, need to revert to proper photo inter in uncompressed TS:
-    if( input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_RCT
-      || input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_ICT )
-      {
-      output.SetPhotometricInterpretation( PhotometricInterpretation::RGB );
-      }
-    assert( output.GetPhotometricInterpretation() == PhotometricInterpretation::RGB
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME1
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME2
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::ARGB
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::PALETTE_COLOR ); // programmer error
+    UpdatePhotometricInterpretation( input, output );
     return true;
     }
   return false;
@@ -101,7 +111,7 @@ bool ImageChangeTransferSyntax::TryRAWCodec(const DataElement &pixelde, Bitmap c
 
 bool ImageChangeTransferSyntax::TryRLECodec(const DataElement &pixelde, Bitmap const &input, Bitmap &output)
 {
-  unsigned long len = input.GetBufferLength();
+  unsigned long len = input.GetBufferLength(); (void)len;
   //assert( len == pixelde.GetByteValue()->GetLength() );
   const TransferSyntax &ts = GetTransferSyntax();
 
@@ -123,17 +133,7 @@ bool ImageChangeTransferSyntax::TryRLECodec(const DataElement &pixelde, Bitmap c
       }
     DataElement &de = output.GetDataElement();
     de.SetValue( out.GetValue() );
-    // when decompressing J2K, need to revert to proper photo inter in uncompressed TS:
-    if( input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_RCT
-      || input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_ICT )
-      {
-      output.SetPhotometricInterpretation( PhotometricInterpretation::RGB );
-      }
-    assert( output.GetPhotometricInterpretation() == PhotometricInterpretation::RGB
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME1
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME2
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::PALETTE_COLOR ); // programmer error
+    UpdatePhotometricInterpretation( input, output );
     return true;
     }
   return false;
@@ -141,7 +141,7 @@ bool ImageChangeTransferSyntax::TryRLECodec(const DataElement &pixelde, Bitmap c
 
 bool ImageChangeTransferSyntax::TryJPEGCodec(const DataElement &pixelde, Bitmap const &input, Bitmap &output)
 {
-  unsigned long len = input.GetBufferLength();
+  unsigned long len = input.GetBufferLength(); (void)len;
   //assert( len == pixelde.GetByteValue()->GetLength() );
   const TransferSyntax &ts = GetTransferSyntax();
 
@@ -182,23 +182,14 @@ bool ImageChangeTransferSyntax::TryJPEGCodec(const DataElement &pixelde, Bitmap
         "Some validator may complains this image is invalid, but would be wrong.");
       }
 
-    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm    
+    // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm
     if( !r )
       {
       return false;
       }
     DataElement &de = output.GetDataElement();
     de.SetValue( out.GetValue() );
-    if( input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_RCT
-     || input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_ICT )
-      {
-      output.SetPhotometricInterpretation( PhotometricInterpretation::RGB );
-      }
-    assert( output.GetPhotometricInterpretation() == PhotometricInterpretation::RGB
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME1
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME2
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::PALETTE_COLOR ); // programmer error
+    UpdatePhotometricInterpretation( input, output );
     // When compressing with JPEG I think planar should always be:
     //output.SetPlanarConfiguration(0);
     // FIXME ! This should be done all the time for all codec:
@@ -208,7 +199,7 @@ bool ImageChangeTransferSyntax::TryJPEGCodec(const DataElement &pixelde, Bitmap
       // HACK
       //gdcm::Image *i = (gdcm::Image*)this;
       //i->SetPhotometricInterpretation( codec.GetPhotometricInterpretation() );
-assert(0);
+      assert(0);
       }
     return true;
     }
@@ -217,7 +208,7 @@ assert(0);
 
 bool ImageChangeTransferSyntax::TryJPEGLSCodec(const DataElement &pixelde, Bitmap const &input, Bitmap &output)
 {
-  unsigned long len = input.GetBufferLength();
+  unsigned long len = input.GetBufferLength(); (void)len;
   //assert( len == pixelde.GetByteValue()->GetLength() );
   const TransferSyntax &ts = GetTransferSyntax();
 
@@ -238,17 +229,7 @@ bool ImageChangeTransferSyntax::TryJPEGLSCodec(const DataElement &pixelde, Bitma
 
     DataElement &de = output.GetDataElement();
     de.SetValue( out.GetValue() );
-    if( input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_RCT
-     || input.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_ICT )
-      {
-      output.SetPhotometricInterpretation( PhotometricInterpretation::RGB );
-      }
-    assert( output.GetPhotometricInterpretation() == PhotometricInterpretation::RGB
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME1
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::MONOCHROME2
-      || output.GetPhotometricInterpretation() == PhotometricInterpretation::PALETTE_COLOR ); // programmer error
- 
+    UpdatePhotometricInterpretation( input, output );
     return r;
     }
   return false;
@@ -256,7 +237,7 @@ bool ImageChangeTransferSyntax::TryJPEGLSCodec(const DataElement &pixelde, Bitma
 
 bool ImageChangeTransferSyntax::TryJPEG2000Codec(const DataElement &pixelde, Bitmap const &input, Bitmap &output)
 {
-  unsigned long len = input.GetBufferLength();
+  unsigned long len = input.GetBufferLength(); (void)len;
   //assert( len == pixelde.GetByteValue()->GetLength() );
   const TransferSyntax &ts = GetTransferSyntax();
 
@@ -266,7 +247,7 @@ bool ImageChangeTransferSyntax::TryJPEG2000Codec(const DataElement &pixelde, Bit
     {
     codec = UserCodec;
     }
-  
+
   if( codec->CanCode( ts ) )
     {
     codec->SetDimensions( input.GetDimensions() );
@@ -291,7 +272,7 @@ bool ImageChangeTransferSyntax::TryJPEG2000Codec(const DataElement &pixelde, Bit
           {
           output.SetPhotometricInterpretation( PhotometricInterpretation::YBR_RCT );
           }
-        else 
+        else
           {
           assert( ts == TransferSyntax::JPEG2000 );
           output.SetPhotometricInterpretation( PhotometricInterpretation::YBR_ICT );
@@ -325,6 +306,7 @@ bool ImageChangeTransferSyntax::TryJPEG2000Codec(const DataElement &pixelde, Bit
     if( !r ) return false;
     DataElement &de = output.GetDataElement();
     de.SetValue( out.GetValue() );
+    UpdatePhotometricInterpretation( input, output );
     return r;
     }
   return false;
@@ -362,9 +344,9 @@ bool ImageChangeTransferSyntax::Change()
 
   // FIXME
   // For now only support raw input, otherwise we would need to first decompress them
-  if( Input->GetTransferSyntax() != TransferSyntax::ImplicitVRLittleEndian 
+  if( (Input->GetTransferSyntax() != TransferSyntax::ImplicitVRLittleEndian
     && Input->GetTransferSyntax() != TransferSyntax::ExplicitVRLittleEndian
-    && Input->GetTransferSyntax() != TransferSyntax::ExplicitVRBigEndian
+    && Input->GetTransferSyntax() != TransferSyntax::ExplicitVRBigEndian)
     || Force )
     {
     // In memory decompression:
@@ -400,8 +382,8 @@ bool ImageChangeTransferSyntax::Change()
     gdcm::ByteValue *bv = new gdcm::ByteValue();
     unsigned long len = Input->GetIconImage().GetBufferLength();
     bv->SetLength( len );
-    bool b = Input->GetIconImage().GetBuffer( (char*)bv->GetPointer() );
-    if( !b )
+    bool bb = Input->GetIconImage().GetBuffer( (char*)bv->GetPointer() );
+    if( !bb )
       {
       return false;
       }
