@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -53,6 +53,16 @@ bool ImageCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
   return false;
 }
 
+void ImageCodec::SetLossyFlag(bool l)
+{
+  LossyFlag = l;
+}
+
+bool ImageCodec::GetLossyFlag() const
+{
+  return LossyFlag;
+}
+
 bool ImageCodec::IsLossy() const
 {
   return LossyFlag;
@@ -63,6 +73,11 @@ void ImageCodec::SetNumberOfDimensions(unsigned int dim)
   NumberOfDimensions = dim;
 }
 
+unsigned int ImageCodec::GetNumberOfDimensions() const
+{
+  return NumberOfDimensions;
+}
+
 
 const PhotometricInterpretation &ImageCodec::GetPhotometricInterpretation() const
 {
@@ -203,6 +218,7 @@ bool ImageCodec::DoPlanarConfiguration(std::istream &is, std::ostream &os)
   delete[] dummy_buffer /*copy*/;
 
   os.write(copy /*dummy_buffer*/, buf_size);
+  delete[] copy;
   return true;
 }
 
