@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmImageWriter_h
-#define __gdcmImageWriter_h
+#ifndef GDCMIMAGEWRITER_H
+#define GDCMIMAGEWRITER_H
 
 #include "gdcmPixmapWriter.h"
 #include "gdcmImage.h"
@@ -48,4 +48,4 @@ private:
 
 } // end namespace gdcm
 
-#endif //__gdcmImageWriter_h
+#endif //GDCMIMAGEWRITER_H
