@@ -416,6 +416,7 @@ bool JPEGBITSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
     assert( (precision - 1) >= 0 );
     this->PF.SetHighBit( precision - 1 );
 
+  this->PlanarConfiguration = 0;
     // Let's check the color space:
     //  JCS_UNKNOWN    -> 0
     //  JCS_GRAYSCALE,    /* monochrome */
@@ -459,6 +460,7 @@ bool JPEGBITSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
       assert( cinfo.num_components == 3 );
       PI = PhotometricInterpretation::YBR_FULL_422;
       this->PF.SetSamplesPerPixel( 3 );
+  this->PlanarConfiguration = 1;
       }
     else if( cinfo.jpeg_color_space == JCS_CMYK )
       {
@@ -478,7 +480,6 @@ bool JPEGBITSCodec::GetHeaderInfo(std::istream &is, TransferSyntax &ts)
       assert( 0 ); //TODO
       }
     }
-  this->PlanarConfiguration = 0;
   if( cinfo.process == JPROC_LOSSLESS )
     {
     int predictor = cinfo.Ss;
@@ -813,12 +814,21 @@ bool JPEGBITSCodec::Decode(std::istream &is, std::ostream &os)
         // correct DICOM file.
         // FIXME FIXME
         /* prevent the library from performing any color space conversion */
+        cinfo.jpeg_color_space = JCS_UNKNOWN;
+        cinfo.out_color_space = JCS_UNKNOWN;
         }
       if ( cinfo.process == JPROC_LOSSLESS )
         {
         //cinfo.jpeg_color_space = JCS_UNKNOWN;
         //cinfo.out_color_space = JCS_UNKNOWN;
         }
+      if( GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL 
+      || GetPhotometricInterpretation() == PhotometricInterpretation::YBR_FULL_422 )
+        {
+        cinfo.jpeg_color_space = JCS_UNKNOWN;
+        cinfo.out_color_space = JCS_UNKNOWN;
+        //this->PlanarConfiguration = 1;
+        }
       break;
     case JCS_CMYK:
       assert( GetPhotometricInterpretation() == PhotometricInterpretation::CMYK );
@@ -1106,7 +1116,8 @@ jpeg_stdio_dest (j_compress_ptr cinfo, /*FILE * */ std::ostream * outfile)
 
 bool JPEGBITSCodec::InternalCode(const char* input, unsigned long len, std::ostream &os)
 {
-  int quality = 100;
+  int quality = 100; (void)len;
+  (void)quality;
   JSAMPLE * image_buffer = (JSAMPLE*)input;	/* Points to large array of R,G,B-order data */
   const unsigned int *dims = this->GetDimensions();
   int image_height = dims[1];	/* Number of rows in image */
