@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -12,8 +12,8 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================*/
-#ifndef __gdcmPVRGcodec_h
-#define __gdcmPVRGcodec_h
+#ifndef GDCMPVRGCODEC_H
+#define GDCMPVRGCODEC_H
 
 #include "gdcmImageCodec.h"
 
@@ -48,4 +48,4 @@ private:
 
 } // end namespace gdcm
 
-#endif //__gdcmPVRGcodec_h
+#endif //GDCMPVRGCODEC_H
