@@ -109,7 +109,7 @@ Attribute<0x0028,0x0004> piat;
     if ( pi == PhotometricInterpretation::PALETTE_COLOR )
       {
       const LookupTable &lut = icon.GetLUT();
-      assert( (pf.GetBitsAllocated() == 8  && pf.GetPixelRepresentation() == 0) 
+      assert( (pf.GetBitsAllocated() == 8  && pf.GetPixelRepresentation() == 0)
            || (pf.GetBitsAllocated() == 16 && pf.GetPixelRepresentation() == 0) );
       // lut descriptor:
       // (0028,1101) US 256\0\16                                 #   6, 3 RedPaletteColorLookupTableDescriptor
@@ -117,13 +117,17 @@ Attribute<0x0028,0x0004> piat;
       // (0028,1103) US 256\0\16                                 #   6, 3 BluePaletteColorLookupTableDescriptor
       // lut data:
       unsigned short length, subscript, bitsize;
-      unsigned short rawlut8[256];
-      unsigned short rawlut16[65536];
-      unsigned short *rawlut = rawlut8;
+      //unsigned short rawlut8[256];
+      std::vector<unsigned short> rawlut8;
+      rawlut8.resize(256);
+      //unsigned short rawlut16[65536];
+      std::vector<unsigned short> rawlut16;
+      unsigned short *rawlut = &rawlut8[0];
       unsigned int lutlen = 256;
       if( pf.GetBitsAllocated() == 16 )
         {
-        rawlut = rawlut16;
+        rawlut16.resize(65536);
+        rawlut = &rawlut16[0];
         lutlen = 65536;
         }
       unsigned int l;
@@ -230,7 +234,6 @@ Attribute<0x0028,0x0004> piat;
 
 bool PixmapWriter::PrepareWrite()
 {
-  //assert( Stream.is_open() );
   File& file = GetFile();
   DataSet& ds = file.GetDataSet();
 
@@ -271,16 +274,15 @@ bool PixmapWriter::PrepareWrite()
     return false;
     }
 
-  // FIXME HACK !
-  if( pf.GetBitsAllocated() == 24 )
     {
-    assert(0);
-    pi = PhotometricInterpretation::RGB;
-    pf.SetBitsAllocated( 8 );
-    pf.SetBitsStored( 8 );
-    pf.SetHighBit( 7 );
-    pf.SetSamplesPerPixel( 3 );
+    assert( pi != PhotometricInterpretation::UNKNOW );
+    const char *pistr = PhotometricInterpretation::GetPIString(pi);
+    DataElement de( Tag(0x0028, 0x0004 ) );
+    de.SetByteValue( pistr, strlen(pistr) );
+    de.SetVR( Attribute<0x0028,0x0004>::GetVR() );
+    ds.Replace( de );
     }
+
   // Pixel Format :
   // (0028,0100) US 8                                        #   2, 1 BitsAllocated
   // (0028,0101) US 8                                        #   2, 1 BitsStored
@@ -313,7 +315,6 @@ bool PixmapWriter::PrepareWrite()
     ds.Replace( planarconf.GetAsDataElement() );
     }
 
-
   // Overlay Data 60xx
   unsigned int nOv = PixelData->GetNumberOfOverlays();
   for( unsigned int ovidx = 0; ovidx < nOv; ++ovidx )
@@ -478,133 +479,6 @@ bool PixmapWriter::PrepareWrite()
   de.SetVL( vl );
   ds.Replace( de );
 
-//      Attribute<0x0028, 0x0006> planarconfiguration;
-//      planarconfiguration.SetValue( PixelData->GetPlanarConfiguration() );
-//      ds.Replace( planarconfiguration.GetAsDataElement() );
-
-  // PhotometricInterpretation
-  // const Tag tphotometricinterpretation(0x0028, 0x0004);
-  //if( !ds.FindDataElement( Tag(0x0028, 0x0004) ) )
-    {
-    assert( pi != PhotometricInterpretation::UNKNOW );
-    const char *pistr = PhotometricInterpretation::GetPIString(pi);
-    DataElement de( Tag(0x0028, 0x0004 ) );
-    de.SetByteValue( pistr, strlen(pistr) );
-    de.SetVR( Attribute<0x0028,0x0004>::GetVR() );
-    ds.Insert( de );
-    //if( pi == PhotometricInterpretation::RGB
-    //  || pi == PhotometricInterpretation::YBR_FULL ) // FIXME
-    //  {
-    //  Attribute<0x0028, 0x0006> planarconfiguration;
-    //  planarconfiguration.SetValue( PixelData->GetPlanarConfiguration() );
-    //  ds.Replace( planarconfiguration.GetAsDataElement() );
-    //  }
-    //else
-    if ( pi == PhotometricInterpretation::PALETTE_COLOR )
-      {
-      const LookupTable &lut = PixelData->GetLUT();
-      assert( lut.Initialized() );
-      assert( (pf.GetBitsAllocated() == 8  && pf.GetPixelRepresentation() == 0) 
-           || (pf.GetBitsAllocated() == 16 && pf.GetPixelRepresentation() == 0) );
-      // lut descriptor:
-      // (0028,1101) US 256\0\16                                 #   6, 3 RedPaletteColorLookupTableDescriptor
-      // (0028,1102) US 256\0\16                                 #   6, 3 GreenPaletteColorLookupTableDescriptor
-      // (0028,1103) US 256\0\16                                 #   6, 3 BluePaletteColorLookupTableDescriptor
-      // lut data:
-      unsigned short length, subscript, bitsize;
-      unsigned short rawlut8[256];
-      unsigned short rawlut16[65536];
-      unsigned short *rawlut = rawlut8;
-      unsigned int lutlen = 256;
-      if( pf.GetBitsAllocated() == 16 )
-        {
-        rawlut = rawlut16;
-        lutlen = 65536;
-        }
-      unsigned int l;
-
-      // FIXME: should I really clear rawlut each time ?
-      // RED
-      memset(rawlut,0,lutlen*2);
-      lut.GetLUT(LookupTable::RED, (unsigned char*)rawlut, l);
-      DataElement redde( Tag(0x0028, 0x1201) );
-      redde.SetVR( VR::OW );
-      redde.SetByteValue( (char*)rawlut, l);
-      ds.Replace( redde );
-      // descriptor:
-      Attribute<0x0028, 0x1101, VR::US, VM::VM3> reddesc;
-      lut.GetLUTDescriptor(LookupTable::RED, length, subscript, bitsize);
-      reddesc.SetValue(length,0); reddesc.SetValue(subscript,1); reddesc.SetValue(bitsize,2);
-      ds.Replace( reddesc.GetAsDataElement() );
-
-      // GREEN
-      memset(rawlut,0,lutlen*2);
-      lut.GetLUT(LookupTable::GREEN, (unsigned char*)rawlut, l);
-      DataElement greende( Tag(0x0028, 0x1202) );
-      greende.SetVR( VR::OW );
-      greende.SetByteValue( (char*)rawlut, l);
-      ds.Replace( greende );
-      // descriptor:
-      Attribute<0x0028, 0x1102, VR::US, VM::VM3> greendesc;
-      lut.GetLUTDescriptor(LookupTable::GREEN, length, subscript, bitsize);
-      greendesc.SetValue(length,0); greendesc.SetValue(subscript,1); greendesc.SetValue(bitsize,2);
-      ds.Replace( greendesc.GetAsDataElement() );
-
-      // BLUE
-      memset(rawlut,0,lutlen*2);
-      lut.GetLUT(LookupTable::BLUE, (unsigned char*)rawlut, l);
-      DataElement bluede( Tag(0x0028, 0x1203) );
-      bluede.SetVR( VR::OW );
-      bluede.SetByteValue( (char*)rawlut, l);
-      ds.Replace( bluede );
-      // descriptor:
-      Attribute<0x0028, 0x1103, VR::US, VM::VM3> bluedesc;
-      lut.GetLUTDescriptor(LookupTable::BLUE, length, subscript, bitsize);
-      bluedesc.SetValue(length,0); bluedesc.SetValue(subscript,1); bluedesc.SetValue(bitsize,2);
-      ds.Replace( bluedesc.GetAsDataElement() );
-      }
-
-    ds.Remove( Tag(0x0028, 0x1221) );
-    ds.Remove( Tag(0x0028, 0x1222) );
-    ds.Remove( Tag(0x0028, 0x1223) );
-
-    }
-
-  // FIXME shouldn't this be done by the ImageApplyLookupTable filter ?
-  if( pi == PhotometricInterpretation::RGB )
-    {
-    // usual tags:
-    ds.Remove( Tag(0x0028, 0x1101) );
-    ds.Remove( Tag(0x0028, 0x1102) );
-    ds.Remove( Tag(0x0028, 0x1103) );
-
-    ds.Remove( Tag(0x0028, 0x1201) );
-    ds.Remove( Tag(0x0028, 0x1202) );
-    ds.Remove( Tag(0x0028, 0x1203) );
-
-    // Dont' forget the segmented one:
-    ds.Remove( Tag(0x0028, 0x1221) );
-    ds.Remove( Tag(0x0028, 0x1222) );
-    ds.Remove( Tag(0x0028, 0x1223) );
-
-    // PaletteColorLookupTableUID ??
-    ds.Remove( Tag(0x0028, 0x1199) );
-    }
-//  Attribute<0x0028, 0x0004> photometricinterpretation;
-//  photometricinterpretation.SetValue( pi );
-//  ds.Replace( photometricinterpretation.GetAsDataElement() );
-Attribute<0x0028,0x0004> piat;
-//const DataElement &pide = ds.GetDataElement( piat.GetTag() );
-//const char *str1 = pide.GetByteValue()->GetPointer();
-{
-    const char *pistr = PhotometricInterpretation::GetPIString(pi);
-    DataElement de( Tag(0x0028, 0x0004 ) );
-    de.SetByteValue( pistr, strlen(pistr) );
-    de.SetVR( piat.GetVR() );
-    ds.Replace( de );
-}
-
-
   // Do Icon Image
   DoIconImage(ds, GetPixmap());
 
@@ -635,68 +509,6 @@ Attribute<0x0028,0x0004> piat;
       }
     }
 
-  // (re)Compute MediaStorage:
-  if( !ds.FindDataElement( Tag(0x0008, 0x0060) ) )
-    {
-    const char *modality = ms.GetModality();
-    DataElement de( Tag(0x0008, 0x0060 ) );
-    de.SetByteValue( modality, strlen(modality) );
-    de.SetVR( Attribute<0x0008, 0x0060>::GetVR() );
-    ds.Insert( de );
-    }
-  else
-    {
-    const ByteValue *bv = ds.GetDataElement( Tag(0x0008, 0x0060 ) ).GetByteValue();
-    std::string modality2;
-    if( bv )
-      {
-      modality2 = std::string( bv->GetPointer(), bv->GetLength() );
-      //assert( modality2.find( ' ' ) == std::string::npos ); // no space ...
-      }
-    else
-      {
-      // remove empty Modality, and set a new one...
-      ds.Remove( Tag(0x0008, 0x0060 ) ); // Modality is Type 1 !
-      assert( ms != MediaStorage::MS_END );
-      }
-/*
-    if( modality2 != ms.GetModality() )
-      {
-      assert( std::string(ms.GetModality()).find( ' ' ) == std::string::npos ); // no space ...
-      DataElement de( Tag(0x0008, 0x0060 ) );
-      de.SetByteValue( ms.GetModality(), strlen(ms.GetModality()) );
-      de.SetVR( Attribute<0x0008, 0x0060>::GetVR() );
-      ds.Insert( de ); // FIXME: should we always replace ?
-      // Well technically you could have a SecondaryCaptureImageStorage with a modality of NM...
-      }
-*/
-    }
-  if( !ds.FindDataElement( Tag(0x0008, 0x0064) ) )
-    {
-    if( ms == MediaStorage::SecondaryCaptureImageStorage )
-      {
-      // (0008,0064) CS [SI]                                     #   2, 1 ConversionType
-      const char conversion[] = "WSD "; // FIXME
-      DataElement de( Tag(0x0008, 0x0064 ) );
-      de.SetByteValue( conversion, strlen(conversion) );
-      de.SetVR( Attribute<0x0008, 0x0064>::GetVR() );
-      ds.Insert( de );
-      }
-    }
-  //if( !ds.FindDataElement( Tag(0x0020, 0x0062) ) )
-  //  {
-  //  if( ms == MediaStorage::SecondaryCaptureImageStorage )
-  //    {
-  //    const char laterality[] = "U "; // FIXME
-  //    DataElement de( Tag(0x0020, 0x0062 ) );
-  //    de.SetByteValue( laterality, strlen(laterality) );
-  //    de.SetVR( Attribute<0x0020, 0x0062>::GetVR() );
-  //    ds.Insert( de );
-  //    }
-  //  }
-
-
-
   // UIDs:
   // (0008,0018) UI [1.3.6.1.4.1.5962.1.1.1.1.3.20040826185059.5457] #  46, 1 SOPInstanceUID
   // (0020,000d) UI [1.3.6.1.4.1.5962.1.2.1.20040826185059.5457] #  42, 1 StudyInstanceUID
@@ -781,7 +593,7 @@ Attribute<0x0028,0x0004> piat;
     }
 
   FileMetaInformation &fmi = file.GetHeader();
-
+  fmi.Clear();
   //assert( ts == TransferSyntax::ImplicitVRLittleEndian );
     {
     const char *tsuid = TransferSyntax::GetTSString( ts );
@@ -791,116 +603,8 @@ Attribute<0x0028,0x0004> piat;
     fmi.Replace( de );
     fmi.SetDataSetTransferSyntax(ts);
     }
-  fmi.Remove( Tag(0x0002,0x0012) ); // Set the Implementation Class UID properly
-  fmi.Remove( Tag(0x0002,0x0013) ); // 
-  fmi.Remove( Tag(0x0002,0x0016) ); // 
   fmi.FillFromDataSet( ds );
 
-  // Some Type 2 Element:
-  // PatientName
-  if( !ds.FindDataElement( Tag(0x0010,0x0010) ) )
-    {
-    DataElement de( Tag(0x0010,0x0010) );
-    de.SetVR( Attribute<0x0010,0x0010>::GetVR() );
-    ds.Insert( de );
-    }
-  // PatientID
-  if( !ds.FindDataElement( Tag(0x0010,0x0020) ) )
-    {
-    DataElement de( Tag(0x0010,0x0020) );
-    de.SetVR( Attribute<0x0010,0x0020>::GetVR() );
-    ds.Insert( de );
-    }
-  // PatientBirthDate
-  if( !ds.FindDataElement( Tag(0x0010,0x0030) ) )
-    {
-    DataElement de( Tag(0x0010,0x0030) );
-    de.SetVR( Attribute<0x0010,0x0030>::GetVR() );
-    ds.Insert( de );
-    }
-  // PatientSex
-  if( !ds.FindDataElement( Tag(0x0010,0x0040) ) )
-    {
-    DataElement de( Tag(0x0010,0x0040) );
-    de.SetVR( Attribute<0x0010,0x0040>::GetVR() );
-    ds.Insert( de );
-    }
-  // Laterality
-  if( false && !ds.FindDataElement( Tag(0x0020,0x0060) ) )
-    {
-    DataElement de( Tag(0x0020,0x0060) );
-    de.SetVR( Attribute<0x0020,0x0060>::GetVR() );
-    ds.Insert( de );
-    }
-  // StudyDate
-  char date[22];
-  const size_t datelen = 8;
-  int res = System::GetCurrentDateTime(date);
-  assert( res );
-  if( !ds.FindDataElement( Tag(0x0008,0x0020) ) )
-    {
-    DataElement de( Tag(0x0008,0x0020) );
-    // Do not copy the whole cstring:
-    de.SetByteValue( date, datelen );
-    de.SetVR( Attribute<0x0008,0x0020>::GetVR() );
-    ds.Insert( de );
-    }
-  // StudyTime
-  const size_t timelen = 6 + 1 + 6; // time + milliseconds
-  Attribute<0x0008, 0x0030> studytime;
-  if( !ds.FindDataElement( studytime.GetTag() ) )
-    {
-    // Do not copy the whole cstring:
-    studytime.SetValue( CSComp(date+datelen, timelen) );
-    ds.Insert( studytime.GetAsDataElement() );
-    }
-  // ReferringPhysicianName
-  if( !ds.FindDataElement( Tag(0x0008,0x0090) ) )
-    {
-    DataElement de( Tag(0x0008,0x0090) );
-    de.SetVR( Attribute<0x0008,0x0090>::GetVR() );
-    ds.Insert( de );
-    }
-  // StudyID
-  if( !ds.FindDataElement( Tag(0x0020,0x0010) ) )
-    {
-    // FIXME: this one is actually bad since the value is needed for DICOMDIR construction
-    DataElement de( Tag(0x0020,0x0010) );
-    de.SetVR( Attribute<0x0020,0x0010>::GetVR() );
-    ds.Insert( de );
-    }
-  // AccessionNumber
-  if( !ds.FindDataElement( Tag(0x0008,0x0050) ) )
-    {
-    DataElement de( Tag(0x0008,0x0050) );
-    de.SetVR( Attribute<0x0008,0x0050>::GetVR() );
-    ds.Insert( de );
-    }
-  // SeriesNumber
-  if( !ds.FindDataElement( Tag(0x0020,0x0011) ) )
-    {
-    DataElement de( Tag(0x0020,0x0011) );
-    de.SetVR( Attribute<0x0020,0x0011>::GetVR() );
-    ds.Insert( de );
-    }
-  // InstanceNumber
-  if( !ds.FindDataElement( Tag(0x0020,0x0013) ) )
-    {
-    DataElement de( Tag(0x0020,0x0013) );
-    de.SetVR( Attribute<0x0020,0x0013>::GetVR() );
-    ds.Insert( de );
-    }
-  // Patient Orientation
-  if( ms == MediaStorage::SecondaryCaptureImageStorage && !ds.FindDataElement( Tag(0x0020,0x0020) ) )
-    {
-    DataElement de( Tag(0x0020,0x0020) );
-    de.SetVR( Attribute<0x0020,0x0020>::GetVR() );
-    ds.Insert( de );
-    }
-  //const char dummy[] = "dummy";
-  //assert( Stream.is_open() );
-  //Stream << dummy;
-
 
   return true;
 }
