@@ -222,7 +222,7 @@ static const char * const gdcmMD5DataImages[][2] = {
 /* gdcm 800 535 1 8 3 */
 { "279e2b0363394a553ff8571cf3540c6c" , "LEADTOOLS_FLOWERS-24-RGB-JpegLossless.dcm" },
 /* gdcm 800 535 1 8 3 */
-{ "6224dc57584aa545a62303f270be44d2" , "LEADTOOLS_FLOWERS-24-RGB-JpegLossy.dcm" },
+{ "38c2784aa485733fef45b6517479a4f5" , "LEADTOOLS_FLOWERS-24-RGB-JpegLossy.dcm" },
 /* gdcm 800 535 1 8 3 */
 { "279e2b0363394a553ff8571cf3540c6c" , "LEADTOOLS_FLOWERS-24-RGB-Uncompressed.dcm" },
 /* gdcm 800 535 1 8 1 */
@@ -346,7 +346,7 @@ static const char * const gdcmMD5DataImages[][2] = {
 /* gdcm 512 512 1 16 1 */
 { "09661bd8516aeb5a6f09239f9ca1b092" , "TOSHIBA_MRT150-16-MONO2-ACR_NEMA_2.dcm" },
 /* gdcm 636 434 1 8 3 */
-{ "437b3b7516a4c91a29edeb5846ec826b" , "US-GE-4AICL142.dcm" },
+{ "23ec8ed09e1ecc353c2e6436a1de6cb2" , "US-GE-4AICL142.dcm" },
 /* gdcm 640 480 1 8 1 */
 { "ba092234639594ee9091b46997532cce" , "US-IRAD-NoPreambleStartWith0003.dcm" },
 /* gdcm 640 480 1 8 1 */
@@ -387,7 +387,7 @@ static const char * const gdcmMD5DataImages[][2] = {
 { "938ac04374eadbe6ac4d7df80e5aa178" , "JDDICOM_Sample1.dcm" },
 // This one can not be decompressed properly with dcmdjpeg. Until
 // they fix dcmdjpeg I'll assume decompression went right
-{ "c40f979bca11742e697d9451c60691e5" , "JDDICOM_Sample2.dcm" },
+{ "33aa469ec024188d692262d03e7108a0" , "JDDICOM_Sample2.dcm" },
 // Same problem
 { "308b1b6fbc01df4dc3fb168830777cb1" , "JDDICOM_Sample3.dcm" },
 // Same thing
@@ -628,7 +628,7 @@ static const char * const gdcmMD5DataImages[][2] = {
 
 { "6396332b75b15bf30b1dd1cd0f212691" , "SIEMENS_MOSAIC_12BitsStored-16BitsJPEG.dcm" },
 { "ba8dae4b43075c7e8562f5addf5f95c3" , "DX_GE_FALCON_SNOWY-VOI.dcm" },
-{ "a03fa65f1a64b40ed62babe0ab5e4f0c" , "JPEG_LossyYBR.dcm" },
+{ "d6fb1fb06318dd305a461db9c84cf825" , "JPEG_LossyYBR.dcm" },
 { "43f33c06d56f239ce9ed5ca0d66a69d2" , "PHILIPS_Brilliance_ExtraBytesInOverlay.dcm" },
 { "dae9d2e2b412646fd0a0f31dc2d17aa4" , "BugGDCM2_UndefItemWrongVL.dcm" },
 
@@ -649,6 +649,10 @@ static const char * const gdcmMD5DataImages[][2] = {
 { "c8698fa1ec0b227113f244954b8e88f4", "multiframegrayscalebytescis.dcm" },
 { "dce1513162a762bf43dcc3c9d5c5c3f7", "multiframetruecolorscis.dcm" },
 
+{ "6bf95a48f366bdf8af3a198c7b723c77", "SinglePrecisionSC.dcm" },
+
+{ "a870a7a7cab8c17646d118ae146be588" , "MR16BitsAllocated_8BitsStored.dcm" },
+
 
 /* Stopping condition */
 { 0 ,0 }
