@@ -16,6 +16,7 @@
 
 int TestPixelFormat(int , char *[])
 {
+  using gdcm::PixelFormat;
   gdcm::PixelFormat pf;
   pf.SetScalarType( gdcm::PixelFormat::UNKNOWN );
   if( pf.GetScalarType() != gdcm::PixelFormat::UNKNOWN )
@@ -41,6 +42,16 @@ int TestPixelFormat(int , char *[])
   std::cout << pf.GetMin() << "," << pf.GetMax() << std::endl;
   pf.SetBitsStored( 32 );
   std::cout << pf.GetMin() << "," << pf.GetMax() << std::endl;
-   
+
+  for(unsigned int i = 0; i < PixelFormat::UNKNOWN; ++i)
+    {
+    PixelFormat::ScalarType st = (PixelFormat::ScalarType)i;
+    pf.SetScalarType( st );
+    gdcm::PixelFormat pf2 = st;
+    std::cout << pf << std::endl;
+    std::cout << pf.GetPixelRepresentation() << std::endl;
+    std::cout << pf.GetScalarTypeAsString() << std::endl;
+    if( pf2 != pf ) return 1;
+    }
   return 0;
 }
