@@ -3,7 +3,7 @@
   Program: GDCM (Grassroots DICOM). A DICOM library
   Module:  $URL$
 
-  Copyright (c) 2006-2009 Mathieu Malaterre
+  Copyright (c) 2006-2010 Mathieu Malaterre
   All rights reserved.
   See Copyright.txt or http://gdcm.sourceforge.net/Copyright.html for details.
 
@@ -19,8 +19,12 @@
 //
 // .SECTION See Also
 
-#ifndef __vtkStringArray_h
-#define __vtkStringArray_h
+#ifndef VTKSTRINGARRAY_H
+#define VTKSTRINGARRAY_H
+
+#ifdef __vtkStringArray_h
+#error Something went terribly wrong
+#endif
 
 #include "vtkObject.h"
 
